// lib/pages/device_managment/garage_door/bloc/event.dart

import 'package:equatable/equatable.dart';
import 'package:flutter/material.dart';

abstract class GarageDoorEvent extends Equatable {
  const GarageDoorEvent();

  @override
  List<Object?> get props => [];
}

class GarageDoorInitialEvent extends GarageDoorEvent {
  final String deviceId;

  const GarageDoorInitialEvent(this.deviceId);

  @override
  List<Object?> get props => [deviceId];
}

class GarageDoorControlEvent extends GarageDoorEvent {
  final String deviceId;
  final dynamic value;
  final String code;

  const GarageDoorControlEvent({required this.deviceId, required this.value, required this.code});

  @override
  List<Object?> get props => [deviceId, value];
}

class AddGarageDoorScheduleEvent extends GarageDoorEvent {
  final String category;
  final TimeOfDay time;
  final bool functionOn;
  final List<bool> selectedDays;

  const AddGarageDoorScheduleEvent({
    required this.category,
    required this.time,
    required this.functionOn,
    required this.selectedDays,
  });
}

class UpdateGarageDoorScheduleEvent extends GarageDoorEvent {
  final String deviceId;
  final String scheduleId;
  final bool enable;
  final bool functionOn;
  final int index;

  const UpdateGarageDoorScheduleEvent({
    required this.deviceId,
    required this.scheduleId,
    required this.enable,
    required this.functionOn,
    required this.index,
  });
}

class DeleteGarageDoorScheduleEvent extends GarageDoorEvent {
  final String deviceId;
  final String scheduleId;
  final int index;

  const DeleteGarageDoorScheduleEvent({
    required this.deviceId,
    required this.scheduleId,
    required this.index,
  });
}

class FetchGarageDoorSchedulesEvent extends GarageDoorEvent {
  final String deviceId;
  final String category;

  const FetchGarageDoorSchedulesEvent({
    required this.deviceId,
    required this.category,
  });
}

class IncreaseGarageDoorDelayEvent extends GarageDoorEvent {
  final String deviceId;

  const IncreaseGarageDoorDelayEvent({required this.deviceId});

  @override
  List<Object?> get props => [deviceId];
}

class DecreaseGarageDoorDelayEvent extends GarageDoorEvent {
  final String deviceId;

  const DecreaseGarageDoorDelayEvent({required this.deviceId});

  @override
  List<Object?> get props => [deviceId];
}

class FetchGarageDoorRecordsEvent extends GarageDoorEvent {
  final String deviceId;
  final String code;

  const FetchGarageDoorRecordsEvent({required this.deviceId, required this.code});

  @override
  List<Object?> get props => [deviceId, code];
}

class BackToGarageDoorGridViewEvent extends GarageDoorEvent {}

class GarageDoorUpdatedEvent extends GarageDoorEvent {}

class UpdateSelectedTimeEvent extends GarageDoorEvent {
  final TimeOfDay? selectedTime;

  const UpdateSelectedTimeEvent(this.selectedTime);

  @override
  List<Object?> get props => [selectedTime];
}

class UpdateSelectedDayEvent extends GarageDoorEvent {
  final int dayIndex;
  final bool isSelected;

  const UpdateSelectedDayEvent(this.dayIndex, this.isSelected);

  @override
  List<Object?> get props => [dayIndex, isSelected];
}

class UpdateFunctionOnEvent extends GarageDoorEvent {
  final bool functionOn;

  const UpdateFunctionOnEvent({required this.functionOn});

  @override
  List<Object?> get props => [functionOn];
}

class InitializeAddScheduleEvent extends GarageDoorEvent {
  final TimeOfDay? selectedTime;
  final List<bool> selectedDays;
  final bool functionOn;
  final bool isEditing;
  final int? index;

  const InitializeAddScheduleEvent({
    required this.selectedTime,
    required this.selectedDays,
    required this.functionOn,
    required this.isEditing,
    this.index,
  });

  @override
  List<Object?> get props => [
        selectedTime,
        selectedDays,
        functionOn,
        isEditing,
        index,
      ];
}
